#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Defaults for iptvtools.

File: constants.py
Author: huxuan
Email: i(at)huxuan.org
"""
CONFIG = 'config.json'
INPUTS = ['https://iptv-org.github.io/iptv/index.m3u']
INTERVAL = 1
LOG_LEVEL = 'INFO'
MIN_HEIGHT = 0
OUTPUT = 'iptvtools.m3u'
SORT_KEYS = ['tvg-id', 'height', 'title']
TEMPLATES = []
TIMEOUT = 10
UDPXY = None
